@@ -3,8 +3,8 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::ReportVersions;
-our $VERSION = '1.100860';
-# ABSTRACT: write a test that reports used module versions
+our $VERSION = '1.100880';
+# ABSTRACT: Write a test that reports used module versions
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
 
@@ -19,11 +19,11 @@ no Moose;
 
 =head1 NAME
 
-Dist::Zilla::Plugin::ReportVersions - write a test that reports used module versions
+Dist::Zilla::Plugin::ReportVersions - Write a test that reports used module versions
 
 =head1 VERSION
 
-version 1.100860
+version 1.100880
 
 =head1 SYNOPSIS
 
@@ -34,7 +34,7 @@ In C<dist.ini>:
 =head1 DESCRIPTION
 
 This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing the
-following files
+following file:
 
   t/000-report-versions.t
 
@@ -482,9 +482,17 @@ BEGIN {
     # Skip modules that either don't want to be loaded directly, such as
     # Module::Install, or that mess with the test count, such as the Test::*
     # modules listed here.
+    #
+    # Moose::Role conflicts if Moose is loaded as well, but Moose::Role is in
+    # the Moose distribution and it's certain that someone who uses
+    # Moose::Role also uses Moose somewhere, so if we disallow Moose::Role,
+    # we'll still get the relevant version number.
+
     my %skip = map { $_ => 1 } qw(
       App::FatPacker
+      Class::Accessor::Classy
       Module::Install
+      Moose::Role
       Test::YAML::Meta
       Test::Pod::Coverage
       Test::Portability::Files
@@ -505,9 +513,12 @@ BEGIN {
 
     diag("Testing with Perl $], $^X");
     for my $module (sort keys %requires) {
-        next if $skip{$module};
-        use_ok $module or BAIL_OUT("can't load $module");
+        if ($skip{$module}) {
+            note "$module doesn't want to be loaded directly, skipping";
+            next;
+        }
         local $SIG{__WARN__} = sub { note "$module: $_[0]" };
+        use_ok $module or BAIL_OUT("can't load $module");
         my $version = $module->VERSION;
         $version = 'undefined' unless defined $version;
         diag("    $module version is $version");
